Nythop - Python, but backwards!
Description: Nythop is an esolang that takes Python and gives it a good shake, letting you write code in reverse for a coding experience like no other!

## Welcome to Nythop

Ready to experience Python in reverse? Nythop is here to revolutionize your coding experience by turning Python on its head – literally. Every line is written backwards, making your code uniquely unreadable!

Why choose Nythop?

- No more indentation wars - they're at the end of the line!
- Comments read from right to left
- Perfectly unreadable code, just as any good esolang should be
- All the confusion of Python, none of the clarity

Learn more about Nythop on the package page

### Code Editor

Start coding in Nyhtop here... # Example: # )"!dlrow olleH"(tnirp

### Output

## Quick Examples

### Hello World

)"!dlrow ,olleH"(tnirp

### Arithmetic Operations

5 = a 3 = b )b + a ,":muS"(tnirp )b - a ,":ecnereffiD"(tnirp )b * a ,":tcudorP"(tnirp )b / a ,":tneitouQ"(tnirp

### Fibonacci

:)n(iccanobif fed 1 ,0 = b ,a :)n(egnar ni _ rof )" "=dne ,a(tnirp b + a ,b = b ,a )01(iccanobif

### Factorial

:)n(lairotcaf fed :0 == n fi 1 nruter :esle )1 - n(lairotcaf * n nruter ))5(lairotcaf ,":5 fo lairotcaF"(tnirp

Note: All code is written from right to left, but executed like normal Python!